__package_name__ = 'spotimote'
__import_name__ = 'spotimote'
__version__ = '1.0.1'
__author__ = 'Rick van Hattem'
__author_email__ = 'Wolph@Wol.ph'
__description__ = '''
Library to control Spotimote from Python
'''
__url__ = 'https://github.com/WoLpH/spotimote'

